@@ -12,6 +12,7 @@ from .helpers import (
     get_element_list,
     get_inner_text_list,
 )
+from .parsers import parse_directory, parse_file, save_file, validate_file
 
 __all__ = (
     "__version__",
@@ -22,9 +23,13 @@ __all__ = (
     "get_element",
     "get_element_list",
     "get_inner_text_list",
+    "parse_directory",
+    "parse_file",
+    "save_file",
     "TIMESTAMP_FORMAT",
     "TYPE_DEFAULTS",
     "TYPE_FUNC_MAP",
+    "validate_file",
 )
 
 
